@@ -256,6 +256,11 @@ Note that if you empty the participant list, C<reset> will be called.
 sub insert {
     my $class = shift;
     my $data = shift;
+
+    die "usage: $class->insert(\\%data, %opts)"
+	unless (Elive::Util::_reftype($data) eq 'HASH'
+		&& @_ % 2 == 0);
+ 
     my %opt = @_;
 
     my $self;
